from pytube import YouTube
import moviepy.editor as mp
from tqdm import tqdm
from storage import (
    VIDEO_PATH, VD_360_PATH, VD_720_PATH, 
    VD_1080_PATH, VD_HQ_PATH, AUDIO_PATH
)
import os
import shutil
import re


def get_url(url):
    """
        Get url typed by user
    """
    try:
        url = YouTube(url)
        return url
    except:
        return None


def get_title(url):
    """
        Return title of stream
    """
    try:
        data = get_url(url)
        return data.title
    except:
        return None


def get_desc(url):
    """
        Return description of stream
    """
    try:
        data = get_url(url)
        return data.description
    except:
        return None


def get_length(url):
    """
        Return length of strema
    """
    try:
        data = get_url(url)
        return data.length
    except:
        return None


def download_video(url, res):
    """
        Download the video according to the resolution chosen by the user
        1 - 360p
        2 - 720p
        3 - 1080p
        4 - HQ - High Quality
    """
    url = get_url(url)
    if res == 1:
        print('Baixando ...')
        stream = url.streams.get_by_itag(18)
        stream.download(output_path=VD_360_PATH)
    elif res == 2:
        print('Baixando ...')
        stream = url.streams.get_by_itag(22)
        stream.download(output_path=VD_720_PATH)
    elif res == 3:
        print('Baixando ...')
        stream = url.streams.get_by_itag(137)
        stream.download(output_path=VD_1080_PATH)       
    elif res == 4:
        print('Baixando ...')
        stream = url.streams.get_highest_resolution()
        stream.download(output_path=VD_HQ_PATH)


def download_audio(url):
    print('Baixando ...')
    url = get_url(url)
    audio = url.streams.filter(only_audio=True).first().download(AUDIO_PATH)
    for file in os.listdir(AUDIO_PATH):
        if re.search('mp4', file):
            mp4_path = os.path.join(AUDIO_PATH, file)
            mp3_path = os.path.join(AUDIO_PATH, os.path.splitext(file)[0] + '.mp3')
            new_file = mp.AudioFileClip(mp4_path)
            new_file.write_audiofile(mp3_path)
            os.remove(mp4_path)


if __name__ == "__main__":
    ...



from time import sleep
from core import (
    get_url, get_title, get_desc, 
    download_video, download_audio,
    # get_length
)    


menu = {
    1: 'Baixar Vídeo',
    2: 'Baixar Áudio',
    3: 'Sair'
}

resol = {
    1: '360p',
    2: '720p',
    3: '1080p',
    4: 'HQ',
}

def main():
    while True:
        while True:

            url = input('\nInforme o endereço web do vídeo que deseja baixar: ').strip()
            if not url:
                print('\nInforme um endereço web válido!')
                sleep(1)
            elif get_title(url) is None:
                print('\nEndereço inválido, tente novamente!')
                sleep(1)
            else:
                print(f'\nTítulo: {get_title(url)}')
                # print(f'\nDuração: {get_length(url)}')
                print(f'\nDescrição: {get_desc(url)}')
                break

        print('\n')
        for k, v in menu.items():
            print(f"{k} - {v}")

        while True:
            try:
                opt = int(input('\nSelecione uma opção: '))
            except ValueError:
                print('Digite um número válido.')
                sleep(1)
            else:
                if opt > len(menu) or opt <= 0:
                    print('Opção inválida!')
                    sleep(1)
                else:
                    break

        if opt == 1:
            print('\n')
            for k, v in resol.items():
                print(f'{k} - {v}')

            while True:
                try:
                    res = int(input('\nSelecione uma resolução: '))
                except ValueError:
                    print('Digite um número válido.')
                    sleep(1)
                else:
                    if res > len(resol) or res <= 0:
                        print('Opção inválida!')
                        sleep(1)
                    else:
                        break

            if res == 1:
                download_video(url, res)
                print('\nVídeo baixado com sucesso!!!')
                sleep(1)
            elif res == 2:
                download_video(url, res)
                print('\nVídeo baixado com sucesso!!!')
                sleep(1)
            elif res == 3:
                download_video(url, res)
                print('\nVídeo baixado com sucesso!!!')
                sleep(1)
            elif res == 4:
                download_video(url, res)
                print('\nVídeo baixado com sucesso!!!')
                sleep(1)

        if opt == 2:
            download_audio(url)
            print('\nÁudio baixado com sucesso!')
            sleep(1)

        if opt == 3:
            print('\nPrograma finalizado!')
            sleep(1)
            break

        print('\nDeseja baixar outro video/audio ?')
        try:
            answer = input('\n1 - SIM / 2 - NAO:   ' ).strip()[0]
        except ValueError:
            print('\nInforme um valor válido!')
            sleep(1)
        else:
            if int(answer) < 1 or int(answer) > 2:
                print('\nResposta incorreta.')
                sleep(1)

        if answer == '2':
            print('\nPrograma finalizado!')
            sleep(1)
            break
